import React from 'react'

import { ErrorComponent } from '../../../../src/components/ErrorComponent'
import { GetServerSideProps } from 'next'
import { serverSideTranslations } from 'next-i18next/serverSideTranslations'
import { useShow } from '@refinedev/core'
import { Show } from '@refinedev/mui'
import { Typography } from '@mui/material'
import CircularProgress from '@mui/material/CircularProgress'
import Box from '@mui/material/Box'
import Chip from '@mui/material/Chip'

const ShowFDO = () => {
  const { queryResult: { isError, error, isLoading, data }, showId } = useShow({
    errorNotification: () => false,
    queryOptions: {
      retry: false
    }
  })

  if (isError) {
    console.log('error', error)
    return <ErrorComponent/>
  }

  return (
    <Show
      isLoading={isLoading}
      title={<Typography variant="h5">{ showId }{ !isLoading && (data?.data?.isFdo ? <Chip label="FDO" color="success" variant="outlined" /> : <Chip label="Not an FDO" color="error" variant="outlined" />)}</Typography>}
    >
      { isLoading && <Box sx={{ textAlign: 'center' }}><CircularProgress/></Box>}
      <Box>This is FDO { showId }</Box>
    </Show>

  )
}

export default ShowFDO

export const getServerSideProps: GetServerSideProps<{}> = async (context) => {
  const translateProps = await serverSideTranslations(context.locale ?? 'en', [
    'common'
  ])

  return {
    props: {
      ...translateProps
    }
  }
}
