import React from 'react'
import Stack from '@mui/material/Stack'
import Paper from '@mui/material/Paper'
import Box from '@mui/material/Box'
import { styled } from '@mui/material/styles'
import { FDO_MANAGER_WEBUI_VERSION } from '../../src/constants'
import { GetServerSideProps } from 'next'
import { serverSideTranslations } from 'next-i18next/serverSideTranslations'

import { useOne, useShow, useApiUrl } from '@refinedev/core'
import { Show } from '@refinedev/mui'
import Link from '@mui/material/Link'

const Item = styled(Paper)(({ theme }) => ({
  backgroundColor: theme.palette.mode === 'dark' ? '#1A2027' : '#fff',
  ...theme.typography.body2,
  padding: theme.spacing(1),
  textAlign: 'left',
  color: theme.palette.text.secondary
}))

const Info = () => {
  const { queryResult: { data, isLoading } } = useShow({ resource: 'info', id: '' })

  console.log('info', data, isLoading)
  const apiUrl = useApiUrl()

  return (
    <Show>
    <Box>
    <Stack>
      <Item>FDO Manager WebUI Version: {FDO_MANAGER_WEBUI_VERSION}</Item>
      <Item>FDO Manager Service Version: {data?.data?.fdoServiceVersion}</Item>
      <Item>FOD Manager API endpoint: <Link href={apiUrl} target="_blank" rel="noopener">{apiUrl}</Link></Item>
      <Item>FDO Manager SDK Version: {data?.data?.fdoSdkVersion}</Item>
    </Stack>
    </Box>
    </Show>
  )
}

export default Info

export const getServerSideProps: GetServerSideProps<{}> = async (context) => {
  const translateProps = await serverSideTranslations(context.locale ?? 'en', [
    'common'
  ])

  return {
    props: {
      ...translateProps
    }
  }
}
